@@ -15,9 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-This module contains Google Ad hook.
-"""
+"""This module contains Google Ad hook."""
 from tempfile import NamedTemporaryFile
 from typing import IO, Any, Dict, Generator, List
 
@@ -27,6 +25,7 @@ from google.ads.google_ads.errors import GoogleAdsException
 from google.ads.google_ads.v2.types import GoogleAdsRow
 from google.api_core.page_iterator import GRPCIterator
 from google.auth.exceptions import GoogleAuthError
+from googleapiclient.discovery import Resource
 
 from airflow import AirflowException
 from airflow.hooks.base_hook import BaseHook
@@ -86,10 +85,8 @@ class GoogleAdsHook(BaseHook):
         self.google_ads_config: Dict[str, Any] = {}
 
     @cached_property
-    def _get_service(self):
-        """
-        Connects and authenticates with the Google Ads API using a service account
-        """
+    def _get_service(self) -> Resource:
+        """Connects and authenticates with the Google Ads API using a service account"""
         with NamedTemporaryFile("w", suffix=".json") as secrets_temp:
             self._get_config()
             self._update_config_with_secret(secrets_temp)
@@ -101,10 +98,8 @@ class GoogleAdsHook(BaseHook):
                 raise
 
     @cached_property
-    def _get_customer_service(self):
-        """
-        Connects and authenticates with the Google Ads API using a service account
-        """
+    def _get_customer_service(self) -> Resource:
+        """Connects and authenticates with the Google Ads API using a service account"""
         with NamedTemporaryFile("w", suffix=".json") as secrets_temp:
             self._get_config()
             self._update_config_with_secret(secrets_temp)
@@ -117,7 +112,8 @@ class GoogleAdsHook(BaseHook):
 
     def _get_config(self) -> None:
         """
-        Gets google ads connection from meta db and sets google_ads_config attribute with returned config file
+        Gets google ads connection from meta db and sets google_ads_config attribute with returned config
+        file
         """
         conn = self.get_connection(self.google_ads_conn_id)
         if "google_ads_client" not in conn.extra_dejson:
