@@ -18,16 +18,18 @@
 from typing import Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core.retry import Retry
-from google.cloud.datacatalog_v1beta1 import DataCatalogClient
-from google.cloud.datacatalog_v1beta1.types import (
+from google.cloud import datacatalog
+from google.cloud.datacatalog_v1beta1 import (
+    CreateTagRequest,
+    DataCatalogClient,
     Entry,
     EntryGroup,
-    FieldMask,
     SearchCatalogRequest,
     Tag,
     TagTemplate,
     TagTemplateField,
 )
+from google.protobuf.field_mask_pb2 import FieldMask
 
 from airflow import AirflowException
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
@@ -68,9 +70,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         self._client: Optional[DataCatalogClient] = None
 
     def get_conn(self) -> DataCatalogClient:
-        """
-        Retrieves client library object that allow access to Cloud Data Catalog service.
-        """
+        """Retrieves client library object that allow access to Cloud Data Catalog service."""
         if not self._client:
             self._client = DataCatalogClient(
                 credentials=self._get_credentials(), client_info=self.client_info
@@ -83,12 +83,12 @@ class CloudDataCatalogHook(GoogleBaseHook):
         location: str,
         entry_group: str,
         entry_id: str,
-        entry: Union[Dict, Entry],
+        entry: Union[dict, Entry],
         project_id: str,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> Entry:
         """
         Creates an entry.
 
@@ -117,10 +117,13 @@ class CloudDataCatalogHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
-        parent = DataCatalogClient.entry_group_path(project_id, location, entry_group)
+        parent = f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}"
         self.log.info('Creating a new entry: parent=%s', parent)
         result = client.create_entry(
-            parent=parent, entry_id=entry_id, entry=entry, retry=retry, timeout=timeout, metadata=metadata
+            request={'parent': parent, 'entry_id': entry_id, 'entry': entry},
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata or (),
         )
         self.log.info('Created a entry: name=%s', result.name)
         return result
@@ -135,7 +138,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> EntryGroup:
         """
         Creates an EntryGroup.
 
@@ -163,16 +166,14 @@ class CloudDataCatalogHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
-        parent = DataCatalogClient.location_path(project_id, location)
+        parent = f"projects/{project_id}/locations/{location}"
         self.log.info('Creating a new entry group: parent=%s', parent)
 
         result = client.create_entry_group(
-            parent=parent,
-            entry_group_id=entry_group_id,
-            entry_group=entry_group,
+            request={'parent': parent, 'entry_group_id': entry_group_id, 'entry_group': entry_group},
             retry=retry,
             timeout=timeout,
-            metadata=metadata,
+            metadata=metadata or (),
         )
         self.log.info('Created a entry group: name=%s', result.name)
 
@@ -184,13 +185,13 @@ class CloudDataCatalogHook(GoogleBaseHook):
         location: str,
         entry_group: str,
         entry: str,
-        tag: Union[Dict, Tag],
+        tag: Union[dict, Tag],
         project_id: str,
         template_id: Optional[str] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> Tag:
         """
         Creates a tag on an entry.
 
@@ -220,15 +221,34 @@ class CloudDataCatalogHook(GoogleBaseHook):
         """
         client = self.get_conn()
         if template_id:
-            template_path = DataCatalogClient.tag_template_path(project_id, location, template_id)
+            template_path = f"projects/{project_id}/locations/{location}/tagTemplates/{template_id}"
             if isinstance(tag, Tag):
                 tag.template = template_path
             else:
                 tag["template"] = template_path
-        parent = DataCatalogClient.entry_path(project_id, location, entry_group, entry)
+        parent = f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}/entries/{entry}"
 
         self.log.info('Creating a new tag: parent=%s', parent)
-        result = client.create_tag(parent=parent, tag=tag, retry=retry, timeout=timeout, metadata=metadata)
+        # HACK: google-cloud-datacatalog has problems with mapping messages where the value is not a
+        # primitive type, so we need to convert it manually.
+        # See: https://github.com/googleapis/python-datacatalog/issues/84
+        if isinstance(tag, dict):
+            tag = Tag(
+                name=tag.get('name'),
+                template=tag.get('template'),
+                template_display_name=tag.get('template_display_name'),
+                column=tag.get('column'),
+                fields={
+                    k: datacatalog.TagField(**v) if isinstance(v, dict) else v
+                    for k, v in tag.get("fields", {}).items()
+                },
+            )
+        request = CreateTagRequest(
+            parent=parent,
+            tag=tag,
+        )
+
+        result = client.create_tag(request=request, retry=retry, timeout=timeout, metadata=metadata or ())
         self.log.info('Created a tag: name=%s', result.name)
 
         return result
@@ -238,12 +258,12 @@ class CloudDataCatalogHook(GoogleBaseHook):
         self,
         location,
         tag_template_id: str,
-        tag_template: Union[Dict, TagTemplate],
+        tag_template: Union[dict, TagTemplate],
         project_id: str,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> TagTemplate:
         """
         Creates a tag template.
 
@@ -269,17 +289,30 @@ class CloudDataCatalogHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
-        parent = DataCatalogClient.location_path(project_id, location)
+        parent = f"projects/{project_id}/locations/{location}"
 
         self.log.info('Creating a new tag template: parent=%s', parent)
+        # HACK: google-cloud-datacatalog has problems with mapping messages where the value is not a
+        # primitive type, so we need to convert it manually.
+        # See: https://github.com/googleapis/python-datacatalog/issues/84
+        if isinstance(tag_template, dict):
+            tag_template = datacatalog.TagTemplate(
+                name=tag_template.get("name"),
+                display_name=tag_template.get("display_name"),
+                fields={
+                    k: datacatalog.TagTemplateField(**v) if isinstance(v, dict) else v
+                    for k, v in tag_template.get("fields", {}).items()
+                },
+            )
 
+        request = datacatalog.CreateTagTemplateRequest(
+            parent=parent, tag_template_id=tag_template_id, tag_template=tag_template
+        )
         result = client.create_tag_template(
-            parent=parent,
-            tag_template_id=tag_template_id,
-            tag_template=tag_template,
+            request=request,
             retry=retry,
             timeout=timeout,
-            metadata=metadata,
+            metadata=metadata or (),
         )
         self.log.info('Created a tag template: name=%s', result.name)
 
@@ -291,12 +324,12 @@ class CloudDataCatalogHook(GoogleBaseHook):
         location: str,
         tag_template: str,
         tag_template_field_id: str,
-        tag_template_field: Union[Dict, TagTemplateField],
+        tag_template_field: Union[dict, TagTemplateField],
         project_id: str,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> TagTemplateField:
         r"""
         Creates a field in a tag template.
 
@@ -327,17 +360,19 @@ class CloudDataCatalogHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
-        parent = DataCatalogClient.tag_template_path(project_id, location, tag_template)
+        parent = f"projects/{project_id}/locations/{location}/tagTemplates/{tag_template}"
 
         self.log.info('Creating a new tag template field: parent=%s', parent)
 
         result = client.create_tag_template_field(
-            parent=parent,
-            tag_template_field_id=tag_template_field_id,
-            tag_template_field=tag_template_field,
+            request={
+                'parent': parent,
+                'tag_template_field_id': tag_template_field_id,
+                'tag_template_field': tag_template_field,
+            },
             retry=retry,
             timeout=timeout,
-            metadata=metadata,
+            metadata=metadata or (),
         )
 
         self.log.info('Created a tag template field: name=%s', result.name)
@@ -354,7 +389,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> None:
         """
         Deletes an existing entry.
 
@@ -377,9 +412,9 @@ class CloudDataCatalogHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
-        name = DataCatalogClient.entry_path(project_id, location, entry_group, entry)
+        name = f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}/entries/{entry}"
         self.log.info('Deleting a entry: name=%s', name)
-        client.delete_entry(name=name, retry=retry, timeout=timeout, metadata=metadata)
+        client.delete_entry(request={'name': name}, retry=retry, timeout=timeout, metadata=metadata or ())
         self.log.info('Deleted a entry: name=%s', name)
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -391,7 +426,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> None:
         """
         Deletes an EntryGroup.
 
@@ -414,10 +449,12 @@ class CloudDataCatalogHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
-        name = DataCatalogClient.entry_group_path(project_id, location, entry_group)
+        name = f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}"
 
         self.log.info('Deleting a entry group: name=%s', name)
-        client.delete_entry_group(name=name, retry=retry, timeout=timeout, metadata=metadata)
+        client.delete_entry_group(
+            request={'name': name}, retry=retry, timeout=timeout, metadata=metadata or ()
+        )
         self.log.info('Deleted a entry group: name=%s', name)
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -431,7 +468,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> None:
         """
         Deletes a tag.
 
@@ -456,10 +493,12 @@ class CloudDataCatalogHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
-        name = DataCatalogClient.tag_path(project_id, location, entry_group, entry, tag)
+        name = (
+            f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}/entries/{entry}/tags/{tag}"
+        )
 
         self.log.info('Deleting a tag: name=%s', name)
-        client.delete_tag(name=name, retry=retry, timeout=timeout, metadata=metadata)
+        client.delete_tag(request={'name': name}, retry=retry, timeout=timeout, metadata=metadata or ())
         self.log.info('Deleted a tag: name=%s', name)
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -472,7 +511,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> None:
         """
         Deletes a tag template and all tags using the template.
 
@@ -497,10 +536,12 @@ class CloudDataCatalogHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
-        name = DataCatalogClient.tag_template_path(project_id, location, tag_template)
+        name = f"projects/{project_id}/locations/{location}/tagTemplates/{tag_template}"
 
         self.log.info('Deleting a tag template: name=%s', name)
-        client.delete_tag_template(name=name, force=force, retry=retry, timeout=timeout, metadata=metadata)
+        client.delete_tag_template(
+            request={'name': name, 'force': force}, retry=retry, timeout=timeout, metadata=metadata or ()
+        )
         self.log.info('Deleted a tag template: name=%s', name)
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -514,7 +555,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> None:
         """
         Deletes a field in a tag template and all uses of that field.
 
@@ -539,11 +580,11 @@ class CloudDataCatalogHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
-        name = DataCatalogClient.field_path(project_id, location, tag_template, field)
+        name = f"projects/{project_id}/locations/{location}/tagTemplates/{tag_template}/fields/{field}"
 
         self.log.info('Deleting a tag template field: name=%s', name)
         client.delete_tag_template_field(
-            name=name, force=force, retry=retry, timeout=timeout, metadata=metadata
+            request={'name': name, 'force': force}, retry=retry, timeout=timeout, metadata=metadata or ()
         )
         self.log.info('Deleted a tag template field: name=%s', name)
 
@@ -557,7 +598,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> Entry:
         """
         Gets an entry.
 
@@ -580,10 +621,12 @@ class CloudDataCatalogHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
-        name = DataCatalogClient.entry_path(project_id, location, entry_group, entry)
+        name = f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}/entries/{entry}"
 
         self.log.info('Getting a entry: name=%s', name)
-        result = client.get_entry(name=name, retry=retry, timeout=timeout, metadata=metadata)
+        result = client.get_entry(
+            request={'name': name}, retry=retry, timeout=timeout, metadata=metadata or ()
+        )
         self.log.info('Received a entry: name=%s', result.name)
 
         return result
@@ -598,7 +641,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> EntryGroup:
         """
         Gets an entry group.
 
@@ -609,8 +652,8 @@ class CloudDataCatalogHook(GoogleBaseHook):
         :param read_mask: The fields to return. If not set or empty, all fields are returned.
 
             If a dict is provided, it must be of the same form as the protobuf message
-            :class:`~google.cloud.datacatalog_v1beta1.types.FieldMask`
-        :type read_mask: Union[Dict, google.cloud.datacatalog_v1beta1.types.FieldMask]
+            :class:`~google.protobuf.field_mask_pb2.FieldMask`
+        :type read_mask: Union[Dict, google.protobuf.field_mask_pb2.FieldMask]
         :param project_id: The ID of the Google Cloud project that owns the entry group.
             If set to ``None`` or missing, the default project_id from the Google Cloud connection is used.
         :type project_id: str
@@ -624,12 +667,15 @@ class CloudDataCatalogHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
-        name = DataCatalogClient.entry_group_path(project_id, location, entry_group)
+        name = f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}"
 
         self.log.info('Getting a entry group: name=%s', name)
 
         result = client.get_entry_group(
-            name=name, read_mask=read_mask, retry=retry, timeout=timeout, metadata=metadata
+            request={'name': name, 'read_mask': read_mask},
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata or (),
         )
 
         self.log.info('Received a entry group: name=%s', result.name)
@@ -645,7 +691,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> TagTemplate:
         """
         Gets a tag template.
 
@@ -666,11 +712,13 @@ class CloudDataCatalogHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
-        name = DataCatalogClient.tag_template_path(project_id, location, tag_template)
+        name = f"projects/{project_id}/locations/{location}/tagTemplates/{tag_template}"
 
         self.log.info('Getting a tag template: name=%s', name)
 
-        result = client.get_tag_template(name=name, retry=retry, timeout=timeout, metadata=metadata)
+        result = client.get_tag_template(
+            request={'name': name}, retry=retry, timeout=timeout, metadata=metadata or ()
+        )
 
         self.log.info('Received a tag template: name=%s', result.name)
 
@@ -714,12 +762,15 @@ class CloudDataCatalogHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
-        parent = DataCatalogClient.entry_path(project_id, location, entry_group, entry)
+        parent = f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}/entries/{entry}"
 
         self.log.info('Listing tag on entry: entry_name=%s', parent)
 
         result = client.list_tags(
-            parent=parent, page_size=page_size, retry=retry, timeout=timeout, metadata=metadata
+            request={'parent': parent, 'page_size': page_size},
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata or (),
         )
 
         self.log.info('Received tags.')
@@ -737,7 +788,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> Tag:
         """
         Gets for a tag with a specific template for a specific entry.
 
@@ -780,7 +831,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> Entry:
         r"""
         Get an entry by target resource name.
 
@@ -813,14 +864,20 @@ class CloudDataCatalogHook(GoogleBaseHook):
         if linked_resource:
             self.log.info('Getting entry: linked_resource=%s', linked_resource)
             result = client.lookup_entry(
-                linked_resource=linked_resource, retry=retry, timeout=timeout, metadata=metadata
+                request={'linked_resource': linked_resource},
+                retry=retry,
+                timeout=timeout,
+                metadata=metadata or (),
             )
         else:
             self.log.info('Getting entry: sql_resource=%s', sql_resource)
             result = client.lookup_entry(
-                sql_resource=sql_resource, retry=retry, timeout=timeout, metadata=metadata
+                request={'sql_resource': sql_resource},
+                retry=retry,
+                timeout=timeout,
+                metadata=metadata or (),
             )
-        self.log.info('Received entry. name=%s.', result.name)
+        self.log.info('Received entry. name=%s', result.name)
 
         return result
 
@@ -835,7 +892,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> TagTemplateField:
         """
         Renames a field in a tag template.
 
@@ -862,18 +919,17 @@ class CloudDataCatalogHook(GoogleBaseHook):
         :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
-        name = DataCatalogClient.field_path(project_id, location, tag_template, field)
+        name = f"projects/{project_id}/locations/{location}/tagTemplates/{tag_template}/fields/{field}"
 
         self.log.info(
             'Renaming field: old_name=%s, new_tag_template_field_id=%s', name, new_tag_template_field_id
         )
 
         result = client.rename_tag_template_field(
-            name=name,
-            new_tag_template_field_id=new_tag_template_field_id,
+            request={'name': name, 'new_tag_template_field_id': new_tag_template_field_id},
             retry=retry,
             timeout=timeout,
-            metadata=metadata,
+            metadata=metadata or (),
         )
 
         self.log.info('Renamed tag template field.')
@@ -948,13 +1004,10 @@ class CloudDataCatalogHook(GoogleBaseHook):
             order_by,
         )
         result = client.search_catalog(
-            scope=scope,
-            query=query,
-            page_size=page_size,
-            order_by=order_by,
+            request={'scope': scope, 'query': query, 'page_size': page_size, 'order_by': order_by},
             retry=retry,
             timeout=timeout,
-            metadata=metadata,
+            metadata=metadata or (),
         )
 
         self.log.info('Received items.')
@@ -965,7 +1018,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
     def update_entry(
         self,
         entry: Union[Dict, Entry],
-        update_mask: Union[Dict, FieldMask],
+        update_mask: Union[dict, FieldMask],
         project_id: str,
         location: Optional[str] = None,
         entry_group: Optional[str] = None,
@@ -973,7 +1026,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> Entry:
         """
         Updates an existing entry.
 
@@ -986,8 +1039,8 @@ class CloudDataCatalogHook(GoogleBaseHook):
             updated.
 
             If a dict is provided, it must be of the same form as the protobuf message
-            :class:`~google.cloud.datacatalog_v1beta1.types.FieldMask`
-        :type update_mask: Union[Dict, google.cloud.datacatalog_v1beta1.types.FieldMask]
+            :class:`~google.protobuf.field_mask_pb2.FieldMask`
+        :type update_mask: Union[Dict, google.protobuf.field_mask_pb2.FieldMask]
         :param location: Required. The location of the entry to update.
         :type location: str
         :param entry_group: The entry group ID for the entry that is being updated.
@@ -1008,7 +1061,9 @@ class CloudDataCatalogHook(GoogleBaseHook):
         """
         client = self.get_conn()
         if project_id and location and entry_group and entry_id:
-            full_entry_name = DataCatalogClient.entry_path(project_id, location, entry_group, entry_id)
+            full_entry_name = (
+                f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}/entries/{entry_id}"
+            )
             if isinstance(entry, Entry):
                 entry.name = full_entry_name
             elif isinstance(entry, dict):
@@ -1020,12 +1075,17 @@ class CloudDataCatalogHook(GoogleBaseHook):
                 "You must provide all the parameters (project_id, location, entry_group, entry_id) "
                 "contained in the name, or do not specify any parameters and pass the name on the object "
             )
-
         name = entry.name if isinstance(entry, Entry) else entry["name"]
         self.log.info("Updating entry: name=%s", name)
 
+        # HACK: google-cloud-datacatalog has a problem with dictionaries for update methods.
+        if isinstance(entry, dict):
+            entry = Entry(**entry)
         result = client.update_entry(
-            entry=entry, update_mask=update_mask, retry=retry, timeout=timeout, metadata=metadata
+            request={'entry': entry, 'update_mask': update_mask},
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata or (),
         )
 
         self.log.info('Updated entry.')
@@ -1045,7 +1105,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> Tag:
         """
         Updates an existing tag.
 
@@ -1059,7 +1119,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
 
             If a dict is provided, it must be of the same form as the protobuf message
             :class:`~google.cloud.datacatalog_v1beta1.types.FieldMask`
-        :type update_mask: Union[Dict, google.cloud.datacatalog_v1beta1.types.FieldMask]
+        :type update_mask: Union[Dict, google.protobuf.field_mask_pb2.FieldMask]
         :param location: Required. The location of the tag to rename.
         :type location: str
         :param entry_group: The entry group ID for the tag that is being updated.
@@ -1082,7 +1142,10 @@ class CloudDataCatalogHook(GoogleBaseHook):
         """
         client = self.get_conn()
         if project_id and location and entry_group and entry and tag_id:
-            full_tag_name = DataCatalogClient.tag_path(project_id, location, entry_group, entry, tag_id)
+            full_tag_name = (
+                f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}/entries/{entry}"
+                f"/tags/{tag_id}"
+            )
             if isinstance(tag, Tag):
                 tag.name = full_tag_name
             elif isinstance(tag, dict):
@@ -1098,8 +1161,14 @@ class CloudDataCatalogHook(GoogleBaseHook):
         name = tag.name if isinstance(tag, Tag) else tag["name"]
         self.log.info("Updating tag: name=%s", name)
 
+        # HACK: google-cloud-datacatalog has a problem with dictionaries for update methods.
+        if isinstance(tag, dict):
+            tag = Tag(**tag)
         result = client.update_tag(
-            tag=tag, update_mask=update_mask, retry=retry, timeout=timeout, metadata=metadata
+            request={'tag': tag, 'update_mask': update_mask},
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata or (),
         )
         self.log.info('Updated tag.')
 
@@ -1108,15 +1177,15 @@ class CloudDataCatalogHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def update_tag_template(
         self,
-        tag_template: Union[Dict, TagTemplate],
-        update_mask: Union[Dict, FieldMask],
+        tag_template: Union[dict, TagTemplate],
+        update_mask: Union[dict, FieldMask],
         project_id: str,
         location: Optional[str] = None,
         tag_template_id: Optional[str] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
         metadata: Optional[Sequence[Tuple[str, str]]] = None,
-    ):
+    ) -> TagTemplate:
         """
         Updates a tag template.
 
@@ -1134,8 +1203,8 @@ class CloudDataCatalogHook(GoogleBaseHook):
             If absent or empty, all of the allowed fields above will be updated.
 
             If a dict is provided, it must be of the same form as the protobuf message
-            :class:`~google.cloud.datacatalog_v1beta1.types.FieldMask`
-        :type update_mask: Union[Dict, google.cloud.datacatalog_v1beta1.types.FieldMask]
+            :class:`~google.protobuf.field_mask_pb2.FieldMask`
+        :type update_mask: Union[Dict, google.protobuf.field_mask_pb2.FieldMask]
         :param location: Required. The location of the tag template to rename.
         :type location: str
         :param tag_template_id: Optional. The tag template ID for the entry that is being updated.
@@ -1154,8 +1223,8 @@ class CloudDataCatalogHook(GoogleBaseHook):
         """
         client = self.get_conn()
         if project_id and location and tag_template:
-            full_tag_template_name = DataCatalogClient.tag_template_path(
-                project_id, location, tag_template_id
+            full_tag_template_name = (
+                f"projects/{project_id}/locations/{location}/tagTemplates/{tag_template_id}"
             )
             if isinstance(tag_template, TagTemplate):
                 tag_template.name = full_tag_template_name
@@ -1172,12 +1241,14 @@ class CloudDataCatalogHook(GoogleBaseHook):
         name = tag_template.name if isinstance(tag_template, TagTemplate) else tag_template["name"]
         self.log.info("Updating tag template: name=%s", name)
 
+        # HACK: google-cloud-datacatalog has a problem with dictionaries for update methods.
+        if isinstance(tag_template, dict):
+            tag_template = TagTemplate(**tag_template)
         result = client.update_tag_template(
-            tag_template=tag_template,
-            update_mask=update_mask,
+            request={'tag_template': tag_template, 'update_mask': update_mask},
             retry=retry,
             timeout=timeout,
-            metadata=metadata,
+            metadata=metadata or (),
         )
         self.log.info('Updated tag template.')
 
@@ -1186,8 +1257,8 @@ class CloudDataCatalogHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def update_tag_template_field(  # pylint: disable=too-many-arguments
         self,
-        tag_template_field: Union[Dict, TagTemplateField],
-        update_mask: Union[Dict, FieldMask],
+        tag_template_field: Union[dict, TagTemplateField],
+        update_mask: Union[dict, FieldMask],
         project_id: str,
         tag_template_field_name: Optional[str] = None,
         location: Optional[str] = None,
@@ -1216,8 +1287,8 @@ class CloudDataCatalogHook(GoogleBaseHook):
             Therefore, enum values can only be added, existing enum values cannot be deleted nor renamed.
 
             If a dict is provided, it must be of the same form as the protobuf message
-            :class:`~google.cloud.datacatalog_v1beta1.types.FieldMask`
-        :type update_mask: Union[Dict, google.cloud.datacatalog_v1beta1.types.FieldMask]
+            :class:`~google.protobuf.field_mask_pb2.FieldMask`
+        :type update_mask: Union[Dict, google.protobuf.field_mask_pb2.FieldMask]
         :param tag_template_field_name: Optional. The name of the tag template field to rename.
         :type tag_template_field_name: str
         :param location: Optional. The location of the tag to rename.
@@ -1240,19 +1311,22 @@ class CloudDataCatalogHook(GoogleBaseHook):
         """
         client = self.get_conn()
         if project_id and location and tag_template and tag_template_field_id:
-            tag_template_field_name = DataCatalogClient.field_path(
-                project_id, location, tag_template, tag_template_field_id
+            tag_template_field_name = (
+                f"projects/{project_id}/locations/{location}/tagTemplates/{tag_template}"
+                f"/fields/{tag_template_field_id}"
             )
 
         self.log.info("Updating tag template field: name=%s", tag_template_field_name)
 
         result = client.update_tag_template_field(
-            name=tag_template_field_name,
-            tag_template_field=tag_template_field,
-            update_mask=update_mask,
+            request={
+                'name': tag_template_field_name,
+                'tag_template_field': tag_template_field,
+                'update_mask': update_mask,
+            },
             retry=retry,
             timeout=timeout,
-            metadata=metadata,
+            metadata=metadata or (),
         )
         self.log.info('Updated tag template field.')
 
