@@ -729,9 +729,7 @@ class BigQueryExecuteQueryOperator(BaseOperator):
                 for s in self.sql
             ]
         else:
-            raise AirflowException(
-                "argument 'sql' of type {} is neither a string nor an iterable".format(type(str))
-            )
+            raise AirflowException(f"argument 'sql' of type {type(str)} is neither a string nor an iterable")
         context['task_instance'].xcom_push(key='job_id', value=job_id)
 
     def on_kill(self) -> None:
@@ -935,7 +933,7 @@ class BigQueryCreateEmptyTableOperator(BaseOperator):
         if not self.schema_fields and self.gcs_schema_object:
             gcs_bucket, gcs_object = _parse_gcs_url(self.gcs_schema_object)
             gcs_hook = GCSHook(
-                google_cloud_storage_conn_id=self.google_cloud_storage_conn_id,
+                gcp_conn_id=self.google_cloud_storage_conn_id,
                 delegate_to=self.delegate_to,
                 impersonation_chain=self.impersonation_chain,
             )
@@ -1176,7 +1174,7 @@ class BigQueryCreateExternalTableOperator(BaseOperator):
 
         if not self.schema_fields and self.schema_object and self.source_format != 'DATASTORE_BACKUP':
             gcs_hook = GCSHook(
-                google_cloud_storage_conn_id=self.google_cloud_storage_conn_id,
+                gcp_conn_id=self.google_cloud_storage_conn_id,
                 delegate_to=self.delegate_to,
                 impersonation_chain=self.impersonation_chain,
             )
@@ -2001,6 +1999,7 @@ class BigQueryInsertJobOperator(BaseOperator):
     template_fields_renderers = {"configuration": "json"}
     ui_color = BigQueryUIColors.QUERY.value
 
+    @apply_defaults
     def __init__(
         self,
         configuration: Dict[str, Any],
