@@ -15,12 +15,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-This module contains a Google Cloud Transfer sensor.
-"""
+"""This module contains a Google Cloud Transfer sensor."""
 from typing import Optional, Sequence, Set, Union
 
-from airflow.providers.google.cloud.hooks.cloud_storage_transfer_service import CloudDataTransferServiceHook
+from airflow.providers.google.cloud.hooks.cloud_storage_transfer_service import (
+    COUNTERS,
+    METADATA,
+    NAME,
+    CloudDataTransferServiceHook,
+)
 from airflow.sensors.base_sensor_operator import BaseSensorOperator
 from airflow.utils.decorators import apply_defaults
 
@@ -84,7 +87,7 @@ class CloudDataTransferServiceJobStatusSensor(BaseSensorOperator):
         self.gcp_cloud_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def poke(self, context):
+    def poke(self, context: dict) -> bool:
         hook = CloudDataTransferServiceHook(
             gcp_conn_id=self.gcp_cloud_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -93,6 +96,9 @@ class CloudDataTransferServiceJobStatusSensor(BaseSensorOperator):
             request_filter={'project_id': self.project_id, 'job_names': [self.job_name]}
         )
 
+        for operation in operations:
+            self.log.info("Progress for operation %s: %s", operation[NAME], operation[METADATA][COUNTERS])
+
         check = CloudDataTransferServiceHook.operations_contain_expected_statuses(
             operations=operations, expected_statuses=self.expected_statuses
         )
