@@ -15,16 +15,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-Base operator for SQL to GCS operators.
-"""
-
+"""Base operator for SQL to GCS operators."""
 import abc
 import json
 import warnings
 from tempfile import NamedTemporaryFile
 from typing import Optional, Sequence, Union
 
+import pyarrow as pa
+import pyarrow.parquet as pq
 import unicodecsv as csv
 
 from airflow.models import BaseOperator
@@ -57,6 +56,8 @@ class BaseSQLToGCSOperator(BaseOperator):
     :type export_format: str
     :param field_delimiter: The delimiter to be used for CSV files.
     :type field_delimiter: str
+    :param null_marker: The null marker to be used for CSV files.
+    :type null_marker: str
     :param gzip: Option to compress file for upload (does not apply to schemas).
     :type gzip: bool
     :param schema: The schema to use, if any. Should be a list of dict or
@@ -102,22 +103,23 @@ class BaseSQLToGCSOperator(BaseOperator):
     def __init__(
         self,
         *,  # pylint: disable=too-many-arguments
-        sql,
-        bucket,
-        filename,
-        schema_filename=None,
-        approx_max_file_size_bytes=1900000000,
-        export_format='json',
-        field_delimiter=',',
-        gzip=False,
-        schema=None,
-        parameters=None,
-        gcp_conn_id='google_cloud_default',
-        google_cloud_storage_conn_id=None,
-        delegate_to=None,
+        sql: str,
+        bucket: str,
+        filename: str,
+        schema_filename: Optional[str] = None,
+        approx_max_file_size_bytes: int = 1900000000,
+        export_format: str = 'json',
+        field_delimiter: str = ',',
+        null_marker: Optional[str] = None,
+        gzip: bool = False,
+        schema: Optional[Union[str, list]] = None,
+        parameters: Optional[dict] = None,
+        gcp_conn_id: str = 'google_cloud_default',
+        google_cloud_storage_conn_id: Optional[str] = None,
+        delegate_to: Optional[str] = None,
         impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
         **kwargs,
-    ):
+    ) -> None:
         super().__init__(**kwargs)
 
         if google_cloud_storage_conn_id:
@@ -136,6 +138,7 @@ class BaseSQLToGCSOperator(BaseOperator):
         self.approx_max_file_size_bytes = approx_max_file_size_bytes
         self.export_format = export_format.lower()
         self.field_delimiter = field_delimiter
+        self.null_marker = null_marker
         self.gzip = gzip
         self.schema = schema
         self.parameters = parameters
@@ -166,7 +169,7 @@ class BaseSQLToGCSOperator(BaseOperator):
         for tmp_file in files_to_upload:
             tmp_file['file_handle'].close()
 
-    def convert_types(self, schema, col_type_dict, row):
+    def convert_types(self, schema, col_type_dict, row) -> list:
         """Convert values from DBAPI to output-friendly formats."""
         return [self.convert_type(value, col_type_dict.get(name)) for name, value in zip(schema, row)]
 
@@ -184,6 +187,8 @@ class BaseSQLToGCSOperator(BaseOperator):
         tmp_file_handle = NamedTemporaryFile(delete=True)
         if self.export_format == 'csv':
             file_mime_type = 'text/csv'
+        elif self.export_format == 'parquet':
+            file_mime_type = 'application/octet-stream'
         else:
             file_mime_type = 'application/json'
         files_to_upload = [
@@ -197,6 +202,9 @@ class BaseSQLToGCSOperator(BaseOperator):
 
         if self.export_format == 'csv':
             csv_writer = self._configure_csv_file(tmp_file_handle, schema)
+        if self.export_format == 'parquet':
+            parquet_schema = self._convert_parquet_schema(cursor)
+            parquet_writer = self._configure_parquet_file(tmp_file_handle, parquet_schema)
 
         for row in cursor:
             # Convert datetime objects to utc seconds, and decimals to floats.
@@ -204,7 +212,15 @@ class BaseSQLToGCSOperator(BaseOperator):
             row = self.convert_types(schema, col_type_dict, row)
 
             if self.export_format == 'csv':
+                if self.null_marker is not None:
+                    row = [value if value is not None else self.null_marker for value in row]
                 csv_writer.writerow(row)
+            elif self.export_format == 'parquet':
+                if self.null_marker is not None:
+                    row = [value if value is not None else self.null_marker for value in row]
+                row_pydic = {col: [value] for col, value in zip(schema, row)}
+                tbl = pa.Table.from_pydict(row_pydic, parquet_schema)
+                parquet_writer.write_table(tbl)
             else:
                 row_dict = dict(zip(schema, row))
 
@@ -229,7 +245,8 @@ class BaseSQLToGCSOperator(BaseOperator):
                 self.log.info("Current file count: %d", len(files_to_upload))
                 if self.export_format == 'csv':
                     csv_writer = self._configure_csv_file(tmp_file_handle, schema)
-
+                if self.export_format == 'parquet':
+                    parquet_writer = self._configure_parquet_file(tmp_file_handle, parquet_schema)
         return files_to_upload
 
     def _configure_csv_file(self, file_handle, schema):
@@ -240,6 +257,30 @@ class BaseSQLToGCSOperator(BaseOperator):
         csv_writer.writerow(schema)
         return csv_writer
 
+    def _configure_parquet_file(self, file_handle, parquet_schema):
+        parquet_writer = pq.ParquetWriter(file_handle.name, parquet_schema)
+        return parquet_writer
+
+    def _convert_parquet_schema(self, cursor):
+        type_map = {
+            'INTERGER': pa.int64(),
+            'FLOAT': pa.float64(),
+            'NUMERIC': pa.float64(),
+            'BIGNUMERIC': pa.float64(),
+            'BOOL': pa.bool_(),
+            'STRING': pa.string(),
+            'BYTES': pa.binary(),
+            'DATE': pa.date32(),
+            'DATETIME': pa.date64(),
+            'TIMESTAMP': pa.timestamp('s'),
+        }
+
+        columns = [field[0] for field in cursor.description]
+        bq_types = [self.field_to_bigquery(field) for field in cursor.description]
+        pq_types = [type_map.get(bq_type, pa.string()) for bq_type in bq_types]
+        parquet_schema = pa.schema(zip(columns, pq_types))
+        return parquet_schema
+
     @abc.abstractmethod
     def query(self):
         """Execute DBAPI query."""
@@ -253,16 +294,14 @@ class BaseSQLToGCSOperator(BaseOperator):
         """Convert a value from DBAPI to output-friendly formats."""
 
     def _get_col_type_dict(self):
-        """
-        Return a dict of column name and column type based on self.schema if not None.
-        """
+        """Return a dict of column name and column type based on self.schema if not None."""
         schema = []
         if isinstance(self.schema, str):
             schema = json.loads(self.schema)
         elif isinstance(self.schema, list):
             schema = self.schema
         elif self.schema is not None:
-            self.log.warning('Using default schema due to unexpected type.' 'Should be a string or list.')
+            self.log.warning('Using default schema due to unexpected type. Should be a string or list.')
 
         col_type_dict = {}
         try:
