@@ -15,10 +15,8 @@
 # specific language governing permissions and limitations
 # under the License.
 
-"""
-Sensor for detecting the completion of DV360 reports.
-"""
-from typing import Dict, Optional, Sequence, Union
+"""Sensor for detecting the completion of DV360 reports."""
+from typing import Optional, Sequence, Union
 
 from airflow import AirflowException
 from airflow.providers.google.marketing_platform.hooks.display_video import GoogleDisplayVideo360Hook
@@ -68,7 +66,7 @@ class GoogleDisplayVideo360ReportSensor(BaseSensorOperator):
         delegate_to: Optional[str] = None,
         impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
         **kwargs,
-    ):
+    ) -> None:
         super().__init__(**kwargs)
 
         self.report_id = report_id
@@ -77,7 +75,7 @@ class GoogleDisplayVideo360ReportSensor(BaseSensorOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def poke(self, context: Dict) -> bool:
+    def poke(self, context: dict) -> bool:
         hook = GoogleDisplayVideo360Hook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -137,7 +135,7 @@ class GoogleDisplayVideo360GetSDFDownloadOperationSensor(BaseSensorOperator):
         impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
         *args,
         **kwargs,
-    ):
+    ) -> None:
         super().__init__(*args, **kwargs)
         self.mode = mode
         self.poke_interval = poke_interval
@@ -147,7 +145,7 @@ class GoogleDisplayVideo360GetSDFDownloadOperationSensor(BaseSensorOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def poke(self, context: Dict) -> bool:
+    def poke(self, context: dict) -> bool:
         hook = GoogleDisplayVideo360Hook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
